@@ -23,6 +23,7 @@ import aws_cdk.aws_appmesh._jsii
 import aws_cdk.aws_appstream._jsii
 import aws_cdk.aws_appsync._jsii
 import aws_cdk.aws_athena._jsii
+import aws_cdk.aws_auditmanager._jsii
 import aws_cdk.aws_autoscaling._jsii
 import aws_cdk.aws_autoscalingplans._jsii
 import aws_cdk.aws_backup._jsii
@@ -48,9 +49,12 @@ import aws_cdk.aws_codestarconnections._jsii
 import aws_cdk.aws_codestarnotifications._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_config._jsii
+import aws_cdk.aws_databrew._jsii
 import aws_cdk.aws_datapipeline._jsii
+import aws_cdk.aws_datasync._jsii
 import aws_cdk.aws_dax._jsii
 import aws_cdk.aws_detective._jsii
+import aws_cdk.aws_devopsguru._jsii
 import aws_cdk.aws_directoryservice._jsii
 import aws_cdk.aws_dlm._jsii
 import aws_cdk.aws_dms._jsii
@@ -67,14 +71,17 @@ import aws_cdk.aws_elasticloadbalancing._jsii
 import aws_cdk.aws_elasticloadbalancingv2._jsii
 import aws_cdk.aws_elasticsearch._jsii
 import aws_cdk.aws_emr._jsii
+import aws_cdk.aws_emrcontainers._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_eventschemas._jsii
+import aws_cdk.aws_fis._jsii
 import aws_cdk.aws_fms._jsii
 import aws_cdk.aws_fsx._jsii
 import aws_cdk.aws_gamelift._jsii
 import aws_cdk.aws_globalaccelerator._jsii
 import aws_cdk.aws_glue._jsii
 import aws_cdk.aws_greengrass._jsii
+import aws_cdk.aws_greengrassv2._jsii
 import aws_cdk.aws_guardduty._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_imagebuilder._jsii
@@ -83,7 +90,10 @@ import aws_cdk.aws_iot._jsii
 import aws_cdk.aws_iot1click._jsii
 import aws_cdk.aws_iotanalytics._jsii
 import aws_cdk.aws_iotevents._jsii
+import aws_cdk.aws_iotsitewise._jsii
 import aws_cdk.aws_iotthingsgraph._jsii
+import aws_cdk.aws_iotwireless._jsii
+import aws_cdk.aws_ivs._jsii
 import aws_cdk.aws_kendra._jsii
 import aws_cdk.aws_kinesis._jsii
 import aws_cdk.aws_kinesisanalytics._jsii
@@ -91,20 +101,27 @@ import aws_cdk.aws_kinesisfirehose._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lakeformation._jsii
 import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_licensemanager._jsii
 import aws_cdk.aws_logs._jsii
+import aws_cdk.aws_lookoutvision._jsii
 import aws_cdk.aws_macie._jsii
 import aws_cdk.aws_managedblockchain._jsii
+import aws_cdk.aws_mediaconnect._jsii
 import aws_cdk.aws_mediaconvert._jsii
 import aws_cdk.aws_medialive._jsii
+import aws_cdk.aws_mediapackage._jsii
 import aws_cdk.aws_mediastore._jsii
 import aws_cdk.aws_msk._jsii
+import aws_cdk.aws_mwaa._jsii
 import aws_cdk.aws_neptune._jsii
+import aws_cdk.aws_networkfirewall._jsii
 import aws_cdk.aws_networkmanager._jsii
 import aws_cdk.aws_opsworks._jsii
 import aws_cdk.aws_opsworkscm._jsii
 import aws_cdk.aws_pinpoint._jsii
 import aws_cdk.aws_pinpointemail._jsii
 import aws_cdk.aws_qldb._jsii
+import aws_cdk.aws_quicksight._jsii
 import aws_cdk.aws_ram._jsii
 import aws_cdk.aws_rds._jsii
 import aws_cdk.aws_redshift._jsii
@@ -113,14 +130,18 @@ import aws_cdk.aws_robomaker._jsii
 import aws_cdk.aws_route53._jsii
 import aws_cdk.aws_route53resolver._jsii
 import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_s3objectlambda._jsii
+import aws_cdk.aws_s3outposts._jsii
 import aws_cdk.aws_sagemaker._jsii
 import aws_cdk.aws_sam._jsii
 import aws_cdk.aws_sdb._jsii
 import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.aws_securityhub._jsii
 import aws_cdk.aws_servicecatalog._jsii
+import aws_cdk.aws_servicecatalogappregistry._jsii
 import aws_cdk.aws_servicediscovery._jsii
 import aws_cdk.aws_ses._jsii
+import aws_cdk.aws_signer._jsii
 import aws_cdk.aws_sns._jsii
 import aws_cdk.aws_sqs._jsii
 import aws_cdk.aws_ssm._jsii
@@ -139,9 +160,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cloudformation-include",
-    "1.73.0",
+    "1.96.0",
     __name__[0:-6],
-    "cloudformation-include@1.73.0.jsii.tgz",
+    "cloudformation-include@1.96.0.jsii.tgz",
 )
 
 __all__ = [
